@@ -34,13 +34,16 @@ def calc_contrast_loss(features,assignment_orig,device):
     
     return -torch.log(positives).mean()*temp
 
+def calc_patch_ent(s,device):    
+    return ((-s/s.sum(dim=-1,keepdim=True) * torch.log(s/s.sum(dim=-1,keepdim=True) + 1e-15)).sum(dim=-1)/torch.log(torch.tensor(s.shape[1],dtype=torch.float32,device=device))).mean()   
+
 def patch_contrast_entropy(x, s, num_nodes, device):
     
     # Calculate contrast acc        
     contrast_loss = calc_contrast_loss(torch.cat([x[i,:num_nodes[i],:] for i in range(s.shape[0])]), torch.cat([s[i,:num_nodes[i],:] for i in range(s.shape[0])]),device)                     
     
     # Calculate Patch Entropy
-    PatchEntropy_loss =((-s/s.sum(dim=-1,keepdim=True) * torch.log(s/s.sum(dim=-1,keepdim=True) + 1e-15)).sum(dim=-1)/torch.log(torch.tensor(s.shape[2],dtype=torch.float32,device=device))).mean()        
+    PatchEntropy_loss = calc_patch_ent(torch.cat([s[i,:num_nodes[i],:] for i in range(s.shape[0])]),device)                     
 
     return contrast_loss, PatchEntropy_loss
     
